use utf8;
use strict;
use warnings FATAL => 'all';

package KUB::Manage::Document;

use KUB::Document -self;

sub date2els() {
	my $date = shift;
	return unless $date;
	my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) = localtime($date);
	return
		[unix => $date],
		[year => $year + 1900],
		[month => sprintf('%02d', $mon + 1)],
		[day => sprintf('%02d', $mday)],
		[wday => $wday || 7],
		[hour => sprintf('%02d', $hour)],
		[minute => sprintf('%02d', $min)],
		[second => sprintf('%02d', $sec)],
	;
}

sub hash2els() {
	my $h = shift;
	my @res;
	while(my ($k, $v) = each(%$h)) {
		push @res, [$k => $v];
	}
	return @res;
}

sub build {
	my $req = $self->req;

	my $mode = defined $req->remove ? 'remove' : $req->edit_valid ? 'edit' : 'add';
	my $stage = $req->success ? 'done' : 'input';

	my $root = $self->construct(manage =>
		[mode => $mode],
		[stage => $stage],
		[user =>
			[uid => $req->aselect_force_login],
			[anr => $req->anr],
		],
		[nonce => $req->create_nonce],
	);

	if(defined $req->cur_name) {
		my $entry = $self->createElement('entry');
		if(defined(my $name = $req->new_name)) {
			$entry->appendChild($self->construct(name => $name));
		}
		if(defined(my $url = $req->new_url)) {
			$entry->appendChild($self->construct(url => $url));
		}
		$entry->appendChild($self->construct(private => $req->private ? 'true' : 'false'));
		$root->appendChild($entry);
	} else {
		$root->appendChild($self->construct(urls => map {
			[url =>
				[num => $_->num],
				[name => $_->name],
				[destination => $_->destination],
				[private => $_->private ? 'true' : 'false'],
				[visits => $_->visits],
				[ctime => date2els($_->ctime)],
				[mtime => date2els($_->mtime)],
				$_->atime ? [atime => date2els($_->atime)] : (),
			]
		} @{$req->urls}));
		$root->appendChild($self->construct(random => $req->random_name));
	}

	my $feedback = $req->feedback;
	if(@$feedback) {
		$root->appendChild($self->construct(feedback => map {
			my ($name, $info) = @$_;
			[$name => hash2els($info)]
		} @$feedback));
	}

	if(my $edit = $req->new_edit) {
		my $owner = $req->edit_owner;
		my $name = $req->edit_name;
		my $url = $req->edit_destination;
		$root->appendChild($self->construct(edit =>
			[num => $edit],
			defined $owner ? [owner => $owner] : (),
			defined $name ? [name => $name] : (),
			defined $url ? [url => $url] : (),
		));
	}

	$self->setDocumentElement($root);
}
